# 🦕 steggynography 🕵️
A simple steganography engine that uses LSB to hide ASCII text within images.

## How to Use
There are two available operations: ```encode``` and ```decode```.

The former operation takes an image of a supported format (see limitations below), an ASCII message to encode within the image and an output image path.

The latter operation is used to retrieve the secret message encoded within the image.
Simply provide it with an already encoded image and an output file to write the message to.

For further information you can access the help with ```steggy --help```.

## Limitations
- Length of message must not exceed 4,294,967,295 characters and must be encoded with ASCII.
- Only works with lossless formats like PNG and BMP.

## Building From Source
Simply clone or fork the [GitHub repository](https://github.com/tomaustindev/steggynography) and run ```pip install ./``` within the directory.
This targets the ```pyproject.toml``` file which creates a new python library named ```steggynography```.

